@@ -1,12 +1,12 @@
 import undetected_chromedriver as uc
 from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
+from selenium.common.exceptions import WebDriverException
 from .cfdefaults import Required_defaults
 from pathlib import Path
 import typing
 import time
 import sys
 import json
-import json
 
 #Not a constant. CAPITAL for more readable syntax
 #If constant is ever declared we will use CONST_VARIABLE_NAME
@@ -15,13 +15,26 @@ STDOUT = False
 DEBUG = False
 DUMMY = False
 
-def de_print(text):
+def de_print(text: str):
     if DEBUG:
-        print(text)
+        text = text.encode('ascii', 'ignore')
+        try:
+            print(text)
+        except UnicodeEncodeError:
+            print("Unicode error occured cannot print")
+        except Exception as e:
+            print("[warn] Error occured on a debugger de", e)
+    
     
 def norm_print(text):
     if STDOUT or DEBUG:
-        print(text)
+        text = text.encode('ascii', 'ignore')
+        try:
+            print(text)
+        except UnicodeEncodeError:
+            print("Unicode error occured cannot print")
+        except Exception as e:
+            print("[warn] Error occured on a debugger norm", e)
 
 def warn_print(text, level: int = 2): # 0-Important, 1-If possible, 2-Unimportant (debug purposes)
     acceptable = STDOUT + DEBUG
@@ -111,7 +124,13 @@ class SiteBrowserProcess:
         options = self.defaults.options_default()
         desired_cap = self.defaults.desired_capabilites_default()
         cdriver_path = self.directory.chromedriver_path() #the function will return None(default), or a str path
-        self.driver =  uc.Chrome(desired_capabilities=desired_cap,options=options,driver_executable_path=cdriver_path,*self.args, **self.kwargs)
+        try:
+            self.driver =  uc.Chrome(desired_capabilities=desired_cap,options=options,driver_executable_path=cdriver_path,*self.args, **self.kwargs)
+        except RuntimeError: #Catch if the objects were reused
+            self.defaults.reset_objects()
+            options = self.defaults.options_default()
+            desired_cap = self.defaults.desired_capabilites_default()
+            self.driver =  uc.Chrome(desired_capabilities=desired_cap,options=options,driver_executable_path=cdriver_path,*self.args, **self.kwargs)
         norm_print("Driver initialized")
         
     def init_cf(self,CFobj: CFBypass = CFBypass):
@@ -125,7 +144,11 @@ class SiteBrowserProcess:
 
     def main(self):
         self.initialize_chromedriver()
-        self.driver.minimize_window()
+        try:
+            self.driver.minimize_window()
+        except WebDriverException as e:
+            warn_print("Failed to minimize window.",level=1)
+            de_print(e)
         return self.load_cf()
         
 
